==> com.liferay.commerce.frontend.js-4.0.10-sources.jar: META-INF/resources/ServiceProvider/commerce-admin-pricing/v2.0/index.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

export {default as discountAPI} from './Discount';
export {default as discountAccountAPI} from './DiscountAccount';
export {default as discountAccountGroupAPI} from './DiscountAccountGroup';
export {default as discountCategoryAPI} from './DiscountCategory';
export {default as discountChannelAPI} from './DiscountChannel';
export {default as discountProductAPI} from './DiscountProduct';
export {default as discountProductGroupAPI} from './DiscountProductGroup';
export {default as discountRuleAPI} from './DiscountRule';
export {default as priceEntryAPI} from './PriceEntry';
export {default as priceListAccountAPI} from './PriceListAccount';
export {default as priceListAccountGroupAPI} from './PriceListAccountGroup';
export {default as priceListChannelAPI} from './PriceListChannel';
export {default as priceModifierCategoryAPI} from './PriceModifierCategory';
export {default as priceModifierProductAPI} from './PriceModifierProduct';
export {default as priceModifierProductGroupAPI} from './PriceModifierProductGroup';

==> com.liferay.commerce.frontend.js-4.0.58-sources.jar: META-INF/resources/ServiceProvider/commerce-admin-pricing/v2.0/index.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

export {default as discountAPI} from './Discount';
export {default as discountAccountAPI} from './DiscountAccount';
export {default as discountAccountGroupAPI} from './DiscountAccountGroup';
export {default as discountCategoryAPI} from './DiscountCategory';
export {default as discountChannelAPI} from './DiscountChannel';
export {default as discountOrderTypeAPI} from './DiscountOrderType';
export {default as discountProductAPI} from './DiscountProduct';
export {default as discountSkuAPI} from './DiscountSku';
export {default as discountProductGroupAPI} from './DiscountProductGroup';
export {default as discountRuleAPI} from './DiscountRule';
export {default as priceEntryAPI} from './PriceEntry';
export {default as priceListAccountAPI} from './PriceListAccount';
export {default as priceListAccountGroupAPI} from './PriceListAccountGroup';
export {default as priceListChannelAPI} from './PriceListChannel';
export {default as priceListOrderTypeAPI} from './PriceListOrderType';
export {default as priceModifierCategoryAPI} from './PriceModifierCategory';
export {default as priceModifierProductAPI} from './PriceModifierProduct';
export {default as priceModifierProductGroupAPI} from './PriceModifierProductGroup';
